@@ -166,6 +166,8 @@ async def test_expand_globs():
         assert len(expanded_paths) == 1
         assert file2_path in expanded_paths
 
+        assert len(await expand_globs([os.path.join(temp_dir, "**", "*.txt")])) == 3
+
 
 def test_expand_path():
     path_with_user = "~/test_dir"
@@ -340,6 +342,26 @@ async def test_parse_cli_args_vectorise():
         assert config.files == ["file1.txt"]
 
 
+@pytest.mark.asyncio
+async def test_parse_cli_args_vectorise_recursive_dir():
+    with patch("sys.argv", ["vectorcode", "vectorise", "-r", "."]):
+        config = await parse_cli_args()
+        assert config.action == CliAction.vectorise
+        assert config.files == ["."]
+        assert config.recursive is True
+        assert config.include_hidden is False
+
+
+@pytest.mark.asyncio
+async def test_parse_cli_args_vectorise_recursive_dir_include_hidden():
+    with patch("sys.argv", ["vectorcode", "vectorise", "-r", "."]):
+        config = await parse_cli_args()
+        assert config.action == CliAction.vectorise
+        assert config.files == ["."]
+        assert config.recursive is True
+        assert config.include_hidden is False
+
+
 @pytest.mark.asyncio
 async def test_parse_cli_args_vectorise_no_files():
     with patch("sys.argv", ["vectorcode", "vectorise"]):
